# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`ora_profile::client`](#ora_profileclient): This is a highly customizable Puppet profile class to define an Oracle client on your system.
* [`ora_profile::client::software`](#ora_profileclientsoftware): Installs the Oracle client software on your system.
* [`ora_profile::database`](#ora_profiledatabase): A short summary of the purpose of this defined type.
* [`ora_profile::database::asm_diskgroup`](#ora_profiledatabaseasm_diskgroup): This class contains the code to create the ASM diskgroups.
* [`ora_profile::database::asm_init_params`](#ora_profiledatabaseasm_init_params): This class configures initialization parameters for the ASM instance
* [`ora_profile::database::asm_listener`](#ora_profiledatabaseasm_listener): This class contains the definition of the Oracle listener process.
* [`ora_profile::database::asm_patches`](#ora_profiledatabaseasm_patches): This class contains the definition for the ASM patches.
* [`ora_profile::database::asm_setup`](#ora_profiledatabaseasm_setup): This class contains the code to install Oracle Grid Infrastructure.
* [`ora_profile::database::asm_software`](#ora_profiledatabaseasm_software): This class contains the code to install Oracle Grid Infrastructure.
* [`ora_profile::database::asm_storage`](#ora_profiledatabaseasm_storage): This class sets up the storage for usage by ASM.
* [`ora_profile::database::asm_storage::afd_label`](#ora_profiledatabaseasm_storageafd_label): A short summary of the purpose of this class
* [`ora_profile::database::asm_storage::asmlib`](#ora_profiledatabaseasm_storageasmlib): This class configures ASMLib devices.
* [`ora_profile::database::asm_storage::nfs`](#ora_profiledatabaseasm_storagenfs): This class will create the specified mountpoint and mount the nfs share there.
* [`ora_profile::database::asm_storage::udev`](#ora_profiledatabaseasm_storageudev): This class will apply udev rules to specified disk devices.
* [`ora_profile::database::cis_controls`](#ora_profiledatabasecis_controls): This class contains the actual code secureing the database.
* [`ora_profile::database::common`](#ora_profiledatabasecommon): This class contains common variables used by more then one class.
* [`ora_profile::database::db_definition`](#ora_profiledatabasedb_definition): This class contains the actual database definition using the `ora_database` type.
* [`ora_profile::database::db_definition_template`](#ora_profiledatabasedb_definition_template): This class contains the actual database definition using the `ora_install::database` class.
* [`ora_profile::database::db_init_params`](#ora_profiledatabasedb_init_params): This class configures initialization parameters for the databases instance(s)
* [`ora_profile::database::db_listener`](#ora_profiledatabasedb_listener): This class contains the definition of the Oracle listener process.
* [`ora_profile::database::db_patches`](#ora_profiledatabasedb_patches): This class contains the definition for the Oracle patches.
* [`ora_profile::database::db_profiles`](#ora_profiledatabasedb_profiles): This class contains the definition for all Oracle profiles you'd like on your system.
* [`ora_profile::database::db_services`](#ora_profiledatabasedb_services): This class contains the definition of all the database services you'd like on your system.
* [`ora_profile::database::db_software`](#ora_profiledatabasedb_software): This class contains the definition of the Oracle software you want to use on this system.
* [`ora_profile::database::db_startup`](#ora_profiledatabasedb_startup): This class contains the definition for the auto startup of Oracle after a system reboot.
* [`ora_profile::database::db_tablespaces`](#ora_profiledatabasedb_tablespaces): This class contains the definition for all the tablespaces you'd like on your system.
* [`ora_profile::database::db_users`](#ora_profiledatabasedb_users): This class contains the definition for all the database users you'd like on your system.
* [`ora_profile::database::disable_thp`](#ora_profiledatabasedisable_thp): This class contains the definition of the Transparent HugePages settings required for running Oracle.
* [`ora_profile::database::em_license`](#ora_profiledatabaseem_license): This class will deploy the Enterprise Modules license.
* [`ora_profile::database::firewall`](#ora_profiledatabasefirewall): This class contains the definition of the firewall settings you need for Oracle.
* [`ora_profile::database::firewall::firewalld`](#ora_profiledatabasefirewallfirewalld): Open up ports for Oracle using the firewalld firewall
* [`ora_profile::database::firewall::iptables`](#ora_profiledatabasefirewalliptables): Open up ports for Oracle using the iptables
* [`ora_profile::database::rac::authenticated_nodes`](#ora_profiledatabaseracauthenticated_nodes): Setup authentication for the cluster nodes.
* [`ora_profile::database::tmpfiles`](#ora_profiledatabasetmpfiles): This class contains the definition all the required OS limit settings on your system.
* [`ora_profile::extracted_database`](#ora_profileextracted_database): A short summary of the purpose of this defined type.
* [`ora_profile::oem_agent`](#ora_profileoem_agent): This is a highly customizable Puppet profile class to define an Oracle Enterprise Manager installation on your system.
* [`ora_profile::oem_agent::software`](#ora_profileoem_agentsoftware): Installs Oracle Enterprse Manager Agent.
* [`ora_profile::oem_server`](#ora_profileoem_server): This is a highly customizable Puppet profile class to define an Oracle Enterprise Manager installation on your system.
* [`ora_profile::oem_server::software`](#ora_profileoem_serversoftware): Installs Oracle Enterprse Manager.
* [`ora_profile::secured_database`](#ora_profilesecured_database): A short summary of the purpose of this class

### Defined types

* [`ora_profile::database::asm_storage::partition`](#ora_profiledatabaseasm_storagepartition): This class adds partition table and partitions to specified device.
* [`ora_profile::database::authenticated_nodes::user_equivalence`](#ora_profiledatabaseauthenticated_nodesuser_equivalence): Setup user equivalence for the specified user on specified nodes.
* [`ora_profile::database::rac::instance`](#ora_profiledatabaseracinstance): Add Undo tablespace, Thread and init parameters for RAC instances

### Functions

* [`set_param`](#set_param): See the file "LICENSE" for the full license governing this code.  Returns the value for requested parameter. Currently supported parameters: 

## Classes

### `ora_profile::client`

ora_profile::client

In it's core just adding:

```
contain ora_profile::client
```

Is enough to get an client installed on your system.

But sometimes you have specific uses cases that are not handled well by the standard classes. This profile class allows you to add your own code to the execution.

## Stages

Defining and starting an Oracle database on you system goes through several stages(These are not puppet stages):

- `packages`         (Install all required packages)
- `groups_and_users` (Create required groups and users)
- `software`         (Install the Oracle client software )

All these stages have a default implementation. This implementation is suitable to get started with. These classed all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

## before classes

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `systctl` stage is done and before the `limits` is done. You can do this by adding the next line to your yaml data:

```yaml
ora_profile::client::before_packages:   my_profile::my_extra_class
```

## after classes

You can do the same when you want to add code after one of the stage classes:

```yaml
ora_profile::client::after_packages:   my_profile::my_extra_class
```

## Skipping

Sometimes organisation use different modules and mechanisms to implement a feature and you want to skip the class:

```yaml
ora_profile::client::packages:   skip
```

## Replacing

Or provide your own implementation:

```yaml
ora_profile::client::packages:   my_profile::my_own_implementation
```

This mechanism can be used for all named stages and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.
++--++

ora_profile::client

In it's core just adding:

```
contain ora_profile::client
```

Is enough to get an client installed on your system.

But sometimes you have specific uses cases that are not handled well by the standard classes. This profile class allows you to add your own code to the execution.

## Stages

Defining an Oracle client on you system goes through several stages(These are not puppet stages):

- `packages`         (Install all required packages)
- `groups_and_users` (Create required groups and users)
- `software`         (Install the Oracle client software )

All these stages have a default implementation. This implementation is suitable to get started with. These classed all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

## before classes

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `packages` stage is done and before the `groups_and_users` is started. You can do this by adding the next line to your yaml data:

```yaml
ora_profile::client::before_groups_and_users:   my_profile::my_extra_class
```

## after classes

You can do the same when you want to add code after one of the stage classes:

```yaml
ora_profile::client::after_packages:   my_profile::my_extra_class
```

## Skipping

Sometimes organisation use different modules and mechanisms to implement a feature and you want to skip the class:

```yaml
ora_profile::client::packages:   skip
```

## Replacing

Or provide your own implementation:

```yaml
ora_profile::client::packages:   my_profile::my_own_implementation
```

This mechanism can be used for all named stages and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.

Here is an example:
```puppet
contain ::ora_profile::client
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::client` class.

##### `before_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_em_license:  my_module::my_class
```

Default value: ``undef``

##### `em_license`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `em_license`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::em_license:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::em_license:  skip
```

Default value: ``undef``

##### `after_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_em_license:  my_module::my_class
```

Default value: ``undef``

##### `before_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `groups_and_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `groups_and_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::groups_and_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::groups_and_users:  skip
```

Default value: ``undef``

##### `after_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `before_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_packages:  my_module::my_class
```

Default value: ``undef``

##### `packages`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `packages`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::packages:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::packages:  skip
```

Default value: ``undef``

##### `after_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_packages:  my_module::my_class
```

Default value: ``undef``

##### `before_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_software:  my_module::my_class
```

Default value: ``undef``

##### `software`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `software`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::software:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::software:  skip
```

Default value: ``undef``

##### `after_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_software:  my_module::my_class
```

Default value: ``undef``

### `ora_profile::client::software`

++--++

ora_profile::client::software

Using this classe you can install the Oracle client software on your system.

--++--

#### Parameters

The following parameters are available in the `ora_profile::client::software` class.

##### `version`

Data type: `Ora_install::Version`

The version that is installed in the used Oracle home.
Puppet uses this value to decide on version specific actions.

##### `file`

Data type: `String[1]`

The source file to use.

##### `oracle_base`

Data type: `Stdlib::Absolutepath`

The base directory to use for the Oracle installation.
The default is : `/u01/app/oracle`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `oracle_home`

Data type: `Stdlib::Absolutepath`

A directory to be used as Oracle home directory for this software.

##### `db_port`

Data type: `Integer`

The IP port to use for database communication.
The default value is: `1521`

##### `user`

Data type: `String[1]`

The user used for the specified installation.
The install class will not create the user for you. You must do that yourself.
The default value is: `oracle`

##### `user_base_dir`

Data type: `Stdlib::Absolutepath`

The directory to use as base directory for the users.

##### `group`

Data type: `String[1]`

The os group to use for these Oracle puppet definitions.
The default value is: `dba`

##### `group_install`

Data type: `String[1]`

The os group to use for installation.
The default value is: `oinstall`

##### `download_dir`

Data type: `Stdlib::Absolutepath`

The directory where the Puppet software puts all downloaded files.
Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
The default value is: `/install`

##### `temp_dir`

Data type: `Stdlib::Absolutepath`

Directory to use for temporary files.

##### `install_type`

Data type: `Enum['Administrator','Runtime','InstantClient','Custom']`

Which type of client software should be installed.

##### `install_options`

Data type: `Optional[Array[String]]`

List of Client Components you would like to install.
This property is considered only if INSTALL_TYPE is set to "Custom"

##### `puppet_download_mnt_point`

Data type: `Optional[String[1]]`

The base path of all remote files for the defined type or class.
The default value is: `puppet:///modules/ora_install`

##### `bash_profile`

Data type: `Boolean`

Create a bash profile for the specified user or not.
Valid values are `true` and `false`.
When you specify a `true` for the parameter, Puppet will create a standard bash profile for the specified user. The bash profile will be placed in a directory named `user_base_dir/user`.
```puppet
ora_install::client { 'Oracle client':
  ...
  bash_profile  => true,
  user          => 'oracle',
  user_base_dir => '/home',
  ...
}
```
This snippet will create a bash profile called `/home/oracle/.bash_profile`.

##### `ora_inventory_dir`

Data type: `Optional[Stdlib::Absolutepath]`

The directory that contains the oracle inventory.
The default value is: `/oracle_base/oraInventory`

##### `logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

log the outputs of Puppet exec or not.
When you specify `true` Puppet will log all output of `exec` types.
Valid values are:
- `true`
- `false`
- `on_failure`

##### `allow_insecure`

Data type: `Boolean`

Allow insecure SSL connection for downloading the software.

### `ora_profile::database`

ora_profile::database

A description of what this defined type does

++--++

ora_profile::database

In it's core just adding:

```
contain ::ora_profile::database
```

Is enough to get an Oracle 12.2 database running on your system.

But sometimes you have specific uses cases that are not handled well by the standard classes. This profile class allows you to add your own code to the execution.

## Stages

Defining and starting an Oracle database on you system goes through several stages(These are not puppet stages):

- `sysctl`           (Set all required sysctl parameters)
- `disable_thp`      (Disable Transparent HugePages)
- `limits`           (Set all required OS limits)
- `packages`         (Install all required packages)
- `groups_and_users` (Create required groups and users)
- `firewall`         (Open required firewall rules)
- `asm_storage`      (Setup storage for use with ASM (skipped by default))
- `asm_software`     (Install Grid Infrastructure/ASM (skipped by default))
- `asm_diskgroup`    (Define all requires ASM diskgroups (skipped by default))
- `db_software`      (Install required Oracle database software)
- `db_patches`       (Install specified Opatch version and install specified patches)
- `db_definition`    (Define the database)
- `db_listener`      (Start the Listener)
- `db_services`      (Define Database Services)
- `db_tablespaces`   (Define all required tablespaces)
- `db_profiles`      (Define all required Oracle profiles)
- `db_users`         (Define all required Oracle users)
- `db_startup`       (Make sure the database restarts after a reboot)

All these stages have a default implementation. This implementation is suitable to get started with. These classed all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

## before classes

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `systctl` stage is done and before the `limits` is done. You can do this by adding the next line to your yaml data:

```yaml
ora_profile::database::before_sysctl:   my_profile::my_extra_class
```

## after classes

You can do the same when you want to add code after one of the stage classes:

```yaml
ora_profile::database::after_sysctl:   my_profile::my_extra_class
```

## Skipping

Sometimes organisation use different modules and mechanisms to implement a feature and you want to skip the class:

```yaml
ora_profile::database::sysctl:   skip
```

## Replacing

Or provide your own implementation:

```yaml
ora_profile::database::sysctl:   my_profile::my_own_implementation
```

This mechanism can be used for all named stages and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.

Look at the description of the stages and their properties.

At this level you can also customize some generic settings. Check the settings for:

- `version`
- `dbname`
- `os_user`
- `dba_group`
- `install_group`
- `source`
- `oracle_base`
- `oracle_home`

Here is an example on how you can do this:

```puppet

class {'ora_profile::database':
  dbname  => 'EM',
  source  => 'http://www.example.com/database_files',
  version => '11.2.0.3',
}

```

--++--

#### Examples

##### 

```puppet
ora_profile::database { 'database_name': }
```

#### Parameters

The following parameters are available in the `ora_profile::database` class.

##### `storage`

Data type: `Enum['local','asm']`

The type of storage used.
The default is `local`

##### `version`

Data type: `Ora_Install::Version`

The version of Oracle you want to install.
The default is : `12.2.0.1`
To customize this consistently use the hiera key `ora_profile::database::version`.

##### `dbname`

Data type: `String[1]`

The name of the database.
The default is `DB01`
To customize this consistently use the hiera key `ora_profile::database::dbname`.

##### `os_user`

Data type: `String[1]`

The OS user to use for Oracle install.
The default is : `oracle`
To customize this consistently use the hiera key `ora_profile::database::os_user`.

##### `dba_group`

Data type: `String[1]`

The group to use for Oracle DBA users.
The default is : `dba`
To customize this consistently use the hiera key `ora_profile::database::dba_group`.

##### `install_group`

Data type: `String[1]`

The group to use for Oracle install.
The default is : `oinstall`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `grid_user`

Data type: `String[1]`

The name of the user that owns the Grid Infrastructure installation.
The default value is: `grid`.

##### `grid_admingroup`

Data type: `String[1]`

The OS group to use for ASM admin.
The default value is: `asmadmin`

##### `source`

Data type: `String[1]`

The location where the classes can find the software.
You can specify a local directory, a Puppet url or an http url.
The default is : `puppet:///modules/software/`
To customize this consistently use the hiera key `ora_profile::database::source`.

##### `oracle_base`

Data type: `Stdlib::Absolutepath`

The base directory to use for the Oracle installation.
The default is : `/u01/app/oracle`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `oracle_home`

Data type: `Stdlib::Absolutepath`

The home directory to use for the Oracle installation.
The default is : `/u01/app/oracle/product/#{version}/db_home1`
To customize this consistently use the hiera key `ora_profile::database::oracle_home`.

##### `ora_inventory_dir`

Data type: `Stdlib::Absolutepath`

The directory that contains the oracle inventory.
The default value is: `/oracle_base/oraInventory`
To customize this consistently use the hiera key `ora_profile::database::ora_inventory_dir`.

##### `grid_base`

Data type: `Stdlib::Absolutepath`

The ORACLE_BASE for the Grid Infrastructure installation.
The default is : `/u01/app/grid/admin`
To customize this consistently use the hiera key `ora_profile::database::grid_base`.

##### `grid_home`

Data type: `Stdlib::Absolutepath`

The oracle home directory to use for the GRID software.
The default value is: `/u01/app/grid/product/12.2.0.1/grid_home1`

##### `db_control_provider`

Data type: `String[1]`

Which provider should be used for the type db_control.
The default value is: `sqlplus`
To customize this consistently use the hiera key `ora_profile::database::db_control_provider`.

##### `download_dir`

Data type: `Stdlib::Absolutepath`

The directory where the Puppet software puts all downloaded files.
Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
The default value is: `/install`
To customize this consistently use the hiera key `ora_profile::database::download_dir`.

##### `temp_dir`

Data type: `Stdlib::Absolutepath`

Directory to use for temporary files.

##### `oracle_user_password`

Data type: `Optional[String]`

The password for the oracle os user.
Only applicable for Windows systems.
To customize this consistently use the hiera key `ora_profile::database::oracle_user_password`.

Default value: ``undef``

##### `master_node`

Data type: `Optional[String]`

The first node in RAC.
This  is the node where the other nodes will clone the software installations from.
To customize this consistently use the hiera key `ora_profile::database::master_node`.

Default value: `$facts['hostname']`

##### `cluster_nodes`

Data type: `Optional[Array]`

An array with cluster node names for RAC.
Example:
```yaml
ora_profile::database::cluster_nodes:
- node1
- node2
```

Default value: ``undef``

##### `em_license`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `em_license`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::em_license:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::em_license:  skip
```

Default value: ``undef``

##### `asm_sysctl`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_sysctl`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_sysctl:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_sysctl:  skip
```

Default value: ``undef``

##### `asm_limits`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_limits`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_limits:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_limits:  skip
```

Default value: ``undef``

##### `authenticated_nodes`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `authenticated_nodes`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::authenticated_nodes:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::authenticated_nodes:  skip
```

Default value: ``undef``

##### `asm_groups_and_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_groups_and_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_groups_and_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_groups_and_users:  skip
```

Default value: ``undef``

##### `asm_packages`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_packages`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_packages:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_packages:  skip
```

Default value: ``undef``

##### `asm_listener`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_listener`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_listener:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_listener:  skip
```

Default value: ``undef``

##### `sysctl`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `sysctl`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::sysctl:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::sysctl:  skip
```

Default value: ``undef``

##### `disable_thp`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `disable_thp`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::disable_thp:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::disable_thp:  skip
```

Default value: ``undef``

##### `limits`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `limits`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::limits:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::limits:  skip
```

Default value: ``undef``

##### `packages`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `packages`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::packages:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::packages:  skip
```

Default value: ``undef``

##### `groups_and_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `groups_and_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::groups_and_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::groups_and_users:  skip
```

Default value: ``undef``

##### `firewall`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `firewall`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::firewall:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::firewall:  skip
```

Default value: ``undef``

##### `asm_storage`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_storage`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_storage:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_storage:  skip
```

Default value: ``undef``

##### `asm_software`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_software`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_software:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_software:  skip
```

Default value: ``undef``

##### `asm_patches`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_patches`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_patches:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_patches:  skip
```

Default value: ``undef``

##### `asm_setup`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_setup`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_setup:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_setup:  skip
```

Default value: ``undef``

##### `asm_init_params`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_init_params`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_init_params:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_init_params:  skip
```

Default value: ``undef``

##### `asm_diskgroup`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `asm_diskgroup`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_diskgroup:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::asm_diskgroup:  skip
```

Default value: ``undef``

##### `db_software`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_software`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_software:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_software:  skip
```

Default value: ``undef``

##### `db_patches`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_patches`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_patches:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_patches:  skip
```

Default value: ``undef``

##### `db_definition`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_definition`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_definition:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_definition:  skip
```

Default value: ``undef``

##### `db_listener`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_listener`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_listener:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_listener:  skip
```

Default value: ``undef``

##### `db_init_params`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_init_params`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_init_params:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_init_params:  skip
```

Default value: ``undef``

##### `db_services`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_services`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_services:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_services:  skip
```

Default value: ``undef``

##### `db_tablespaces`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_tablespaces`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_tablespaces:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_tablespaces:  skip
```

Default value: ``undef``

##### `db_profiles`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_profiles`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_profiles:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_profiles:  skip
```

Default value: ``undef``

##### `db_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_users:  skip
```

Default value: ``undef``

##### `db_startup`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_startup`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_startup:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::db_startup:  skip
```

Default value: ``undef``

##### `before_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_em_license:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_sysctl:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_limits` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_limits:  my_module::my_class
```

Default value: ``undef``

##### `before_authenticated_nodes`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `authenticated_nodes` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_authenticated_nodes:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_packages:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_listener`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_listener` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_listener:  my_module::my_class
```

Default value: ``undef``

##### `before_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_sysctl:  my_module::my_class
```

Default value: ``undef``

##### `before_disable_thp`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `disable_thp` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_disable_thp:  my_module::my_class
```

Default value: ``undef``

##### `before_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_limits:  my_module::my_class
```

Default value: ``undef``

##### `before_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_packages:  my_module::my_class
```

Default value: ``undef``

##### `before_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `before_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_firewall:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_storage`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_storage` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_storage:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_software:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_patches`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_patches` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_patches:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_setup`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_setup` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_setup:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_init_params`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_init_params` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_init_params:  my_module::my_class
```

Default value: ``undef``

##### `before_asm_diskgroup`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `asm_diskgroup` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_asm_diskgroup:  my_module::my_class
```

Default value: ``undef``

##### `before_db_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_software:  my_module::my_class
```

Default value: ``undef``

##### `before_db_patches`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_patches` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_patches:  my_module::my_class
```

Default value: ``undef``

##### `before_db_definition`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_definition` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_definition:  my_module::my_class
```

Default value: ``undef``

##### `before_db_listener`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_listener` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_listener:  my_module::my_class
```

Default value: ``undef``

##### `before_db_init_params`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_init_params` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_init_params:  my_module::my_class
```

Default value: ``undef``

##### `before_db_services`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_services` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_services:  my_module::my_class
```

Default value: ``undef``

##### `before_db_tablespaces`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_tablespaces` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_tablespaces:  my_module::my_class
```

Default value: ``undef``

##### `before_db_profiles`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_profiles` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_profiles:  my_module::my_class
```

Default value: ``undef``

##### `before_db_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_users:  my_module::my_class
```

Default value: ``undef``

##### `before_db_startup`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_startup` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_db_startup:  my_module::my_class
```

Default value: ``undef``

##### `after_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_em_license:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_sysctl:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_limits` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_limits:  my_module::my_class
```

Default value: ``undef``

##### `after_authenticated_nodes`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `authenticated_nodes` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_authenticated_nodes:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_packages:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_listener`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_listener` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_listener:  my_module::my_class
```

Default value: ``undef``

##### `after_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_sysctl:  my_module::my_class
```

Default value: ``undef``

##### `after_disable_thp`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `disable_thp` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_disable_thp:  my_module::my_class
```

Default value: ``undef``

##### `after_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_limits:  my_module::my_class
```

Default value: ``undef``

##### `after_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_packages:  my_module::my_class
```

Default value: ``undef``

##### `after_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `after_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_firewall:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_storage`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_storage` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_storage:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_software:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_patches`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_patches` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_patches:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_setup`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_setup` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_setup:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_init_params`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_init_params` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_init_params:  my_module::my_class
```

Default value: ``undef``

##### `after_asm_diskgroup`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `asm_diskgroup` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_asm_diskgroup:  my_module::my_class
```

Default value: ``undef``

##### `after_db_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_software:  my_module::my_class
```

Default value: ``undef``

##### `after_db_patches`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_patches` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_patches:  my_module::my_class
```

Default value: ``undef``

##### `after_db_definition`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_definition` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_definition:  my_module::my_class
```

Default value: ``undef``

##### `after_db_listener`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_listener` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_listener:  my_module::my_class
```

Default value: ``undef``

##### `after_db_init_params`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_init_params` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_init_params:  my_module::my_class
```

Default value: ``undef``

##### `after_db_services`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_services` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_services:  my_module::my_class
```

Default value: ``undef``

##### `after_db_tablespaces`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_tablespaces` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_tablespaces:  my_module::my_class
```

Default value: ``undef``

##### `after_db_profiles`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_profiles` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_profiles:  my_module::my_class
```

Default value: ``undef``

##### `after_db_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_users:  my_module::my_class
```

Default value: ``undef``

##### `after_db_startup`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_startup` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_db_startup:  my_module::my_class
```

Default value: ``undef``

##### `tmpfiles`

Data type: `Optional[String]`



Default value: ``undef``

##### `before_tmpfiles`

Data type: `Optional[String]`



Default value: ``undef``

##### `after_tmpfiles`

Data type: `Optional[String]`



Default value: ``undef``

### `ora_profile::database::asm_diskgroup`

++--++

ora_profile::database::asm_diskgroup

Here you can customize some of the attributes of your database.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_diskgroup` class.

##### `disks`

Data type: `Hash`

A hash with the diskgroups that will be created.
The default value is:
```yaml
ora_profile::database::asm_diskgroup::disks:
  DATA:
    disks:
    - diskname: 'DATA_0000'
      path: '/nfs_client/asm_sda_nfs_b1'
    - diskname: 'DATA_0001'
      path: '/nfs_client/asm_sda_nfs_b2'
  RECO:
    disks:
    - diskname: 'RECO_0000'
      path: '/nfs_client/asm_sda_nfs_b3'
    - diskname: 'RECO_0001'
      path: '/nfs_client/asm_sda_nfs_b4'
```

Default value: `{}`

### `ora_profile::database::asm_init_params`

++--++

ora_profile::database::asm_init_params

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_init_params` class.

##### `parameters`

Data type: `Hash`

The Hash with parameters that need to be configured.
The keys of the hash represent the parameter you want to set.
Notation: '<scope>/<parameter_name>[:for_sid][@sid]'
```yaml
ora_profile::database::asm_init_params::parameters:
  memory/asm_power_limit:
    ensure: present
    value: 1024
  spfile/asm_power_limit:
    ensure: present
    value: 1024
```
```yaml
ora_profile::database::db_init_params::parameters:
  memory/archive_lag_target:
    ensure: present
    value: 1800
  spfile/archive_lag_target:
    ensure: present
    value: 1800
```
See: [ora_init_params](https://www.enterprisemodules.com/docs/ora_config/ora_init_param.html)

Default value: `{}`

### `ora_profile::database::asm_listener`

++--++

ora_profile::database::asm_listener

It installs the specified version of the SQL*net software and start's the listener.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_listener` class.

##### `oracle_home`

Data type: `Stdlib::Absolutepath`

The home directory to use for the Oracle installation.
The default is : `/u01/app/oracle/product/#{version}/db_home1`
To customize this consistently use the hiera key `ora_profile::database::oracle_home`.

##### `oracle_base`

Data type: `Stdlib::Absolutepath`

The base directory to use for the Oracle installation.
The default is : `/u01/app/oracle`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `sqlnet_version`

Data type: `Ora_install::ShortVersion`

The SQLnet version to use.
The default is: 12.2

##### `dbname`

Data type: `String[1]`

The name of the database.
The default is `DB01`
To customize this consistently use the hiera key `ora_profile::database::dbname`.

### `ora_profile::database::asm_patches`

++--++

ora_profile::database::asm_patches

It also contains the definition of the required `Opatch` version.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_patches` class.

##### `level`

Data type: `String[1]`

The patch level the database or grid infrastructure should be patched to.
Default value is: `NONE`
Valid values depend on your database/grid version, but it should like like below:
- `OCT2018RU`
- `JAN2019RU`
- `APR2019RU`
- etc...

##### `patch_file`

Data type: `String[1]`

The file containing the required Opatch version.
The default value is: `p6880880_122010_Linux-x86-64`

##### `opversion`

Data type: `String[1]`

The version of OPatch that is needed.
If it is not installed, Puppet will install the specfied version.
The default value is: `12.2.0.1.13`

##### `patch_list`

Data type: `Hash`

The list of patches to apply.
The default value is : `{}`

##### `logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

log the outputs of Puppet exec or not.
When you specify `true` Puppet will log all output of `exec` types.
Valid values are:
- `true`
- `false`
- `on_failure`

Default value: `lookup({name => 'logoutput', default_value => 'on_failure'})`

### `ora_profile::database::asm_setup`

ora_profile::asm_software

Here you can customize some of the attributes of your database.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.
++--++

ora_profile::database::asm_setup

Here you can customize some of the attributes of your database.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

   The type of storage to use.
   Valid values are:
   - `ASM_STORAGE`          (versions = 11)
   - `FILE_SYSTEM_STORAGE`  (versions <= 12.1)
   - `LOCAL_ASM_STORAGE`    (versions >= 12.1)
   - `CLIENT_ASM_STORAGE`   (versions >= 12.2)
   - `FLEX_ASM_STORAGE`     (versions >= 12.1)
   The default value is: `undef`

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_setup` class.

##### `version`

Data type: `Ora_Install::Version`

The version of Oracle you want to install.
The default is : `12.2.0.1`
To customize this consistently use the hiera key `ora_profile::database::version`.

##### `dirs`

Data type: `Array[Stdlib::Absolutepath]`

The directories to create as part of the setup.
The default value is:
```yaml
ora_profile::database::asm_setup::dirs:
- /u01
- /u01/app/grid
- /u01/app/grid/admin
- /u01/app/grid/product
```

##### `file_name`

Data type: `String[1]`

The file name containing the Oracle Grid Infrastructure software kit.
The default is: `linuxx64_12201_grid_home`

##### `asm_sys_password`

Data type: `Easy_type::Password`

The `sys` password to use for ASM.
The default is: `Welcome01`
To customize this consistently use the hiera key `ora_profile::database::asm_software::asm_sys_password`.

##### `disk_discovery_string`

Data type: `String[1]`

The disk discovery string for ASM.
The default value is: `/nfs_client/asm*`
To customize this consistently use the hiera key `ora_profile::database::asm_software::disk_discovery_string`.

##### `asm_diskgroup`

Data type: `String[1]`

The name of the ASM diskgroup to use.
The default value is: `DATA`
To customize this consistently use the hiera key `ora_profile::database::asm_software::asm_diskgroup`.

##### `asm_disks`

Data type: `String[1]`

List of disks to create a ASM DiskGroup.
The default value is: `/nfs_client/asm_sda_nfs_b1,/nfs_client/asm_sda_nfs_b2`
To customize this consistently use the hiera key `ora_profile::database::asm_software::asm_disks`.

##### `group`

Data type: `String[1]`

The dba group for ASM.
The default is : `asmdba`
To customize this consistently use the hiera key `ora_profile::database::asm_software::group`.

##### `oper_group`

Data type: `String[1]`

The oper group for ASM.
The default is : `asmoper`
To customize this consistently use the hiera key `ora_profile::database::asm_software::oper_group`.

##### `asm_group`

Data type: `String[1]`

The admin group for ASM.
The default is : `asmadmin`
To customize this consistently use the hiera key `ora_profile::database::asm_software::asm_group`.

##### `configure_afd`

Data type: `Boolean`

Specify whether or not to configure ASM Filter Driver instead of ASMLib.
The default value is: `false`
To customize this consistently use the hiera key `ora_profile::database::asm_software::configure_afd`.

##### `grid_type`

Data type: `Enum['CRS_CONFIG','HA_CONFIG','UPGRADE','CRS_SWONLY','HA_SWONLY']`

The type of grid.
Valid values are:
- `HA_CONFIG`
- `CRS_CONFIG`
- `HA_SWONLY`   (versions > 11)
- `UPGRADE`
- `CRS_SWONLY`
The default value is: `HA_CONFIG`
To customize this consistently use the hiera key `ora_profile::database::asm_software::grid_type`.

##### `disk_redundancy`

Data type: `Enum['EXTENDED','EXTERNAL','FLEX','HIGH','NORMAL']`

The disk redundancy for the initial diskgroup to setup ASM.
Valid values are:
- `EXTENDED`
- `EXTERNAL`
- `FLEX`
- `HIGH`
- `NORMAL`
The default value is: `EXTERNAL`

##### `bash_profile`

Data type: `Boolean`

Whether or not to deploy bash_profile for $os_user or $grid_user
The default is : `true`

##### `disks_failgroup_names`

Data type: `Optional[String[1]]`

A comma seperated list of device and failure group name.
Valid values are:
- `/dev/sdb,CRSFG1,/dev/sdc,CRSFG2,/dev/sdd,CRSFG3`                                 (NORMAL redundancy)
- `/dev/sdb,,/dev/sdc,,/dev/sdd,,/dev/sde,`                                         (EXTERNAL redundancy)
- `/dev/sdb,CRSFG1,/dev/sdc,CRSFG2,/dev/sdd,CRSFG3,/dev/sde,CRSFG4,/dev/sdf,CRSFG5` (HIGH redundancy)
The default value is: `/nfs_client/asm_sda_nfs_b1,`

##### `cluster_name`

Data type: `Optional[String[1]]`

The name of the cluster.
The default value is: `undef`

##### `scan_name`

Data type: `Optional[String[1]]`

The hostname to use for the SCAN service.
The default value is: `undef`

##### `scan_port`

Data type: `Optional[Integer]`

The IP portnumber to use for the SCAN service.
The default value is: `undef`

##### `cluster_node_types`

Data type: `Optional[String[1]]`

The names of the nodes in the RAC cluster.
Valid values are:
- `node1:node1-vip,node2:node2-vip`                     (version >= 11 <= 12.1)
- `node1:node1-vip:HUB,node2:node2-vip:LEAF`            (version >= 12.1 Flex Cluster)
- `node1,node2`                                         (version = 12.2 Application Cluster)
- `node1:node1-vip:HUB:site1,node2:node2-vip:HUB:site2` (version = 12.2 Extended Cluster)
The default value is: `undef`

##### `network_interface_list`

Data type: `Optional[String[1]]`

The list of interfaces to use for RAC.The value should be a comma separated strings where each string is as shown below```InterfaceName:SubnetAddress:InterfaceType```where InterfaceType can be either "1", "2", "3", "4" or "5" (1 indicates public, 2 indicates private, 3 indicates the interface is not used, 4 indicates ASM and 5 indicates ASM & Private)The default value is: `undef`

##### `storage_option`

Data type: `Optional[Enum['FLEX_ASM_STORAGE','CLIENT_ASM_STORAGE','LOCAL_ASM_STORAGE','FILE_SYSTEM_STORAGE','ASM_STORAGE']]`



### `ora_profile::database::asm_software`

++--++

ora_profile::database::asm_software

Here you can customize some of the attributes of your database.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

   The type of storage to use.
   Valid values are:
   - `ASM_STORAGE`          (versions = 11)
   - `FILE_SYSTEM_STORAGE`  (versions <= 12.1)
   - `LOCAL_ASM_STORAGE`    (versions >= 12.1)
   - `CLIENT_ASM_STORAGE`   (versions >= 12.2)
   - `FLEX_ASM_STORAGE`     (versions >= 12.1)
   The default value is: `undef`

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_software` class.

##### `version`

Data type: `Ora_Install::Version`

The version of Oracle Grid Infrastructure you want to install.
The default is : `12.2.0.1`
To customize this consistently use the hiera key `ora_profile::database::asm_software::version`.

##### `dirs`

Data type: `Array[Stdlib::Absolutepath]`

The directories to create as part of the installation.
The default value is:
```yaml
ora_profile::database::asm_software::dirs:
- /u01
- /u01/app/grid
- /u01/app/grid/admin
- /u01/app/grid/product
```

##### `file_name`

Data type: `String[1]`

The file name containing the Oracle Grid Infrastructure software kit.
The default is: `linuxx64_12201_grid_home`

##### `asm_sys_password`

Data type: `Easy_type::Password`

The `sys` password to use for ASM.
The default is: `Welcome01`
To customize this consistently use the hiera key `ora_profile::database::asm_software::asm_sys_password`.

##### `disk_discovery_string`

Data type: `String[1]`

The disk discovery string for ASM.
The default value is: `/nfs_client/asm*`
To customize this consistently use the hiera key `ora_profile::database::asm_software::disk_discovery_string`.

##### `asm_diskgroup`

Data type: `String[1]`

The name of the ASM diskgroup to use.
The default value is: `DATA`
To customize this consistently use the hiera key `ora_profile::database::asm_software::asm_diskgroup`.

##### `asm_disks`

Data type: `String[1]`

List of disks to create a ASM DiskGroup.
The default value is: `/nfs_client/asm_sda_nfs_b1,/nfs_client/asm_sda_nfs_b2`
To customize this consistently use the hiera key `ora_profile::database::asm_software::asm_disks`.

##### `group`

Data type: `String[1]`

The dba group for ASM.
The default is : `asmdba`
To customize this consistently use the hiera key `ora_profile::database::asm_software::group`.

##### `oper_group`

Data type: `String[1]`

The oper group for ASM.
The default is : `asmoper`
To customize this consistently use the hiera key `ora_profile::database::asm_software::oper_group`.

##### `asm_group`

Data type: `String[1]`

The admin group for ASM.
The default is : `asmadmin`
To customize this consistently use the hiera key `ora_profile::database::asm_software::asm_group`.

##### `configure_afd`

Data type: `Boolean`

Specify whether or not to configure ASM Filter Driver instead of ASMLib.
The default value is: `false`
To customize this consistently use the hiera key `ora_profile::database::asm_software::configure_afd`.

##### `grid_type`

Data type: `Enum['CRS_CONFIG','HA_CONFIG','UPGRADE','CRS_SWONLY','HA_SWONLY']`

The type of grid.
Valid values are:
- `HA_CONFIG`
- `CRS_CONFIG`
- `HA_SWONLY`   (versions > 11)
- `UPGRADE`
- `CRS_SWONLY`
The default value is: `HA_CONFIG`
To customize this consistently use the hiera key `ora_profile::database::asm_software::grid_type`.

##### `disk_redundancy`

Data type: `Enum['EXTENDED','EXTERNAL','FLEX','HIGH','NORMAL']`

The disk redundancy for the initial diskgroup to setup ASM.
Valid values are:
- `EXTENDED`
- `EXTERNAL`
- `FLEX`
- `HIGH`
- `NORMAL`
The default value is: `EXTERNAL`

##### `install_task`

Data type: `Enum['ALL','EXTRACT']`

The installation task that should be executed.

##### `bash_profile`

Data type: `Boolean`

Whether or not to deploy bash_profile for $os_user or $grid_user
The default is : `true`

##### `bash_additions`

Data type: `String`

The text to add at the end of the bash_profile.
This parameter will only be used when you have specified `true` for the parameter `bash_profile`
The default value is an empty string.

##### `disks_failgroup_names`

Data type: `Optional[String[1]]`

A comma seperated list of device and failure group name.
Valid values are:
- `/dev/sdb,CRSFG1,/dev/sdc,CRSFG2,/dev/sdd,CRSFG3`                                 (NORMAL redundancy)
- `/dev/sdb,,/dev/sdc,,/dev/sdd,,/dev/sde,`                                         (EXTERNAL redundancy)
- `/dev/sdb,CRSFG1,/dev/sdc,CRSFG2,/dev/sdd,CRSFG3,/dev/sde,CRSFG4,/dev/sdf,CRSFG5` (HIGH redundancy)
The default value is: `/nfs_client/asm_sda_nfs_b1,`

##### `cluster_name`

Data type: `Optional[String[1]]`

The name of the cluster.
The default value is: `undef`

##### `scan_name`

Data type: `Optional[String[1]]`

The hostname to use for the SCAN service.
The default value is: `undef`

##### `scan_port`

Data type: `Optional[Integer]`

The IP portnumber to use for the SCAN service.
The default value is: `undef`

##### `cluster_node_types`

Data type: `Optional[String[1]]`

The names of the nodes in the RAC cluster.
Valid values are:
- `node1:node1-vip,node2:node2-vip`                     (version >= 11 <= 12.1)
- `node1:node1-vip:HUB,node2:node2-vip:LEAF`            (version >= 12.1 Flex Cluster)
- `node1,node2`                                         (version = 12.2 Application Cluster)
- `node1:node1-vip:HUB:site1,node2:node2-vip:HUB:site2` (version = 12.2 Extended Cluster)
The default value is: `undef`

##### `network_interface_list`

Data type: `Optional[String[1]]`

The list of interfaces to use for RAC.The value should be a comma separated strings where each string is as shown below```InterfaceName:SubnetAddress:InterfaceType```where InterfaceType can be either "1", "2", "3", "4" or "5" (1 indicates public, 2 indicates private, 3 indicates the interface is not used, 4 indicates ASM and 5 indicates ASM & Private)The default value is: `undef`

##### `storage_option`

Data type: `Optional[Enum['FLEX_ASM_STORAGE','CLIENT_ASM_STORAGE','LOCAL_ASM_STORAGE','FILE_SYSTEM_STORAGE','ASM_STORAGE']]`



### `ora_profile::database::asm_storage`

++--++

ora_profile::database::asm_storage

Here you can customize some of the attributes of your storage.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_storage` class.

##### `storage_type`

Data type: `Enum['nfs','asmlib','afd','raw']`

The type of ASM storage to use.
Valid values are:
- `nfs`
- `asmlib`
- `afd`
- `raw`
The default value is: `nfs`.

##### `nfs_mountpoint`

Data type: `Optional[Stdlib::Absolutepath]`

The mountpoint where the NFS volume will be mounted.
The default value is: `/nfs_client`.

##### `nfs_export`

Data type: `Optional[Stdlib::Absolutepath]`

The name of the NFS volume that will be mounted to nfs_mountpoint.
The default value is: `/home/nfs_server_data`.

##### `nfs_server`

Data type: `Optional[String[1]]`

The name of the NFS server.
The default value is: `localhost`.

##### `disk_devices`

Data type: `Optional[Hash]`

The disk devices that should be used.
Dependant on value specified for `ora_profile::database::asm_storage::storage_type`
Here is an example:
```yaml
ora_profile::database::asm_storage::disk_devices:
  asm_data01:
    size: 8192
    uuid: '1ATA_VBOX_HARDDISK_VB00000000-01000000'
    label: 'DATA1'
```

##### `scan_exclude`

Data type: `Optional[String[1]]`

Specify which devices to exclude from scanning for ASMLib.
The default value is: `undef`

### `ora_profile::database::asm_storage::afd_label`

ora_profile::database::asm_storage::afd_label

#### Examples

##### 

```puppet
include ora_profile::database::asm_storage::afd_label
```

### `ora_profile::database::asm_storage::asmlib`

++--++

ora_profile::database::asm_storage::asmlib

Here is an example:

```puppet
  include ora_profile::database::asm_storage::asmlib
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_storage::asmlib` class.

##### `grid_user`

Data type: `String[1]`

The name of the user that owns the Grid Infrastructure installation.
The default value is: `grid`.

##### `grid_admingroup`

Data type: `String[1]`

The OS group to use for ASM admin.
The default value is: `asmadmin`

##### `disk_devices`

Data type: `Hash`

The disk devices that should be used.
Dependant on value specified for `ora_profile::database::asm_storage::storage_type`
Here is an example:
```yaml
ora_profile::database::asm_storage::disk_devices:
  asm_data01:
    size: 8192
    uuid: '1ATA_VBOX_HARDDISK_VB00000000-01000000'
    label: 'DATA1'
```

##### `scan_exclude`

Data type: `Optional[String[1]]`

The devices that need to be excluded during scanning of the devices.

### `ora_profile::database::asm_storage::nfs`

++--++

ora_profile::database::asm_storage::nfs

Here is an example:

```puppet
  include ora_profile::database::asm_storage::nfs
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_storage::nfs` class.

##### `grid_user`

Data type: `String[1]`

The name of the user that owns the Grid Infrastructure installation.
The default value is: `grid`.

##### `grid_admingroup`

Data type: `String[1]`

The OS group to use for ASM admin.
The default value is: `asmadmin`

##### `nfs_mountpoint`

Data type: `Stdlib::Absolutepath`

The mountpoint where the NFS volume will be mounted.
The default value is: `/nfs_client`.

##### `nfs_export`

Data type: `Stdlib::Absolutepath`

The name of the NFS volume that will be mounted to nfs_mountpoint.
The default value is: `/home/nfs_server_data`.

##### `nfs_server`

Data type: `String[1]`

The name of the NFS server.
The default value is: `localhost`.

### `ora_profile::database::asm_storage::udev`

++--++

ora_profile::database::asm_storage::udev

Here is an example:

```puppet
  include ora_profile::database::asm_storage::udev
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_storage::udev` class.

##### `grid_user`

Data type: `String[1]`

The name of the user that owns the Grid Infrastructure installation.
The default value is: `grid`.

##### `grid_admingroup`

Data type: `String[1]`

The OS group to use for ASM admin.
The default value is: `asmadmin`

##### `disk_devices`

Data type: `Hash`

The disk devices that should be used.
Dependant on value specified for `ora_profile::database::asm_storage::storage_type`
Here is an example:
```yaml
ora_profile::database::asm_storage::disk_devices:
  asm_data01:
    size: 8192
    uuid: '1ATA_VBOX_HARDDISK_VB00000000-01000000'
    label: 'DATA1'
```

### `ora_profile::database::cis_controls`

++--++

ora_profile::database::cis_controls

Here you ca customise the securtiy by specifying the CIS rules you *don't* want to apply.


When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::secured_database](./secured_database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::cis_controls` class.

##### `dbname`

Data type: `String[1]`

The name of the database.
The default is `DB01`
To customize this consistently use the hiera key `ora_profile::database::dbname`.

##### `product_version`

Data type: `Optional[String[1]]`

The database version of the CIS benchmark you want to apply.
Although not very logical, you **can** apply an older (or newer) database version to your database.
If you also don't specify a `db_version`, Puppet will detect the version of Oracle running and use this to determine the `db_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Oracle version is. In that case, the ora_secured::ensure_cis defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Oracle for specified sid is available.

##### `doc_version`

Data type: `Optional[String[1]]`

The version of the CIS benchmark you want to apply to your database.
When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`.

##### `skip_list`

Data type: `Optional[Array[String[1]]]`

This is the list of controls that you want to skip.
By default this value is empty, meaning `ora_secured::ensure_cis` will apply **ALL** controls. You must specify the name of the control.

### `ora_profile::database::common`

Common variables used by more then one class

++--++

ora_profile::database::common

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::common` class.

##### `version`

The version of Oracle you want to install.
The default is : `12.2.0.1`
To customize this consistently use the hiera key `ora_profile::database::version`.

##### `download_dir`

The directory where the Puppet software puts all downloaded files.
Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
The default value is: `/install`
To customize this consistently use the hiera key `ora_profile::database::download_dir`.

##### `install_group`

The group to use for Oracle install.
The default is : `oinstall`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `master_node`

The first node in RAC.
This  is the node where the other nodes will clone the software installations from.
To customize this consistently use the hiera key `ora_profile::database::master_node`.

##### `ora_inventory_dir`

The directory that contains the oracle inventory.
The default value is: `/oracle_base/oraInventory`
To customize this consistently use the hiera key `ora_profile::database::ora_inventory_dir`.

##### `grid_home`

The ORACLE_HOME for the Grid Infrastructure installation.
The default is : `/u01/app/grid/product/12.2.0.1/grid_home1`
To customize this consistently use the hiera key `ora_profile::database::grid_home`.

##### `grid_base`

The ORACLE_BASE for the Grid Infrastructure installation.
The default is : `/u01/app/grid/admin`
To customize this consistently use the hiera key `ora_profile::database::grid_base`.

##### `grid_user`

The name of the user that owns the Grid Infrastructure installation.
The default value is: `grid`.

##### `temp_dir`

Directory to use for temporary files.

##### `source`

The location where the classes can find the software.
You can specify a local directory, a Puppet url or an http url.
The default is : `puppet:///modules/software/`
To customize this consistently use the hiera key `ora_profile::database::source`.

##### `cluster_nodes`

An array with cluster node names for RAC.
Example:
```yaml
ora_profile::database::cluster_nodes:
- node1
- node2
```

##### `oracle_user_password`

The password for the oracle os user.
Only applicable for Windows systems.
To customize this consistently use the hiera key `ora_profile::database::oracle_user_password`.

##### `db_control_provider`

Which provider should be used for the type db_control.
The default value is: `sqlplus`
To customize this consistently use the hiera key `ora_profile::database::db_control_provider`.

##### `patch_window`

The patch window in which you want to do the patching.
Every time puppet runs outside of this patcn windows, puppet will detect the patches are not installed, but puppet will not shutdown the database and apply the patches.
an example on how to use this is:
        patch_window => '2:00 - 4:00'

##### `patch_levels`

Defines all the patch levels for both database and grid infrastructure formost common versions 12.
2, 18c and 19c.
The default values look like the example below.
In addition to all the parameters for ora_opatch, except sub_patches and source, (see [ora_opatch]https://www.enterprisemodules.com/docs/ora_install/ora_opatch.html) the following parameters can be specified:
        db_sub_patches: Array of sub patches applicable for database installations
        grid_sub_patches: Array of sub patches applicable for grid infrastructure installations
        file: zipfile that contains the patch
        type: 'one-off' or 'psu'
an example on how to use this is:
```yaml
ora_profile::database::patch_levels:
  '19.0.0.0':
    OCT2020RU:
      "31750108-GIRU-19.9.0.0.201020":
        file:                  "p31750108_190000_Linux-x86-64.zip"
        db_sub_patches:        ['31771877','31772784']
        grid_sub_patches:      ['31771877','31772784','31773437','31780966']
```

### `ora_profile::database::db_definition`

++--++

ora_profile::database::db_definition

Here you can customize some of the attributes of your database.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_definition` class.

##### `version`

Data type: `Ora_Install::Version`

The version of Oracle you want to install.
The default is : `12.2.0.1`
To customize this consistently use the hiera key `ora_profile::database::version`.

##### `oracle_home`

Data type: `Stdlib::Absolutepath`

The home directory to use for the Oracle installation.
The default is : `/u01/app/oracle/product/#{version}/db_home1`
To customize this consistently use the hiera key `ora_profile::database::oracle_home`.

##### `oracle_base`

Data type: `Stdlib::Absolutepath`

The base directory to use for the Oracle installation.
The default is : `/u01/app/oracle`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `os_user`

Data type: `String[1]`

The OS user to use for Oracle install.
The default is : `oracle`
To customize this consistently use the hiera key `ora_profile::database::os_user`.

##### `install_group`

Data type: `String[1]`

The group to use for Oracle install.
The default is : `oinstall`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `dbname`

Data type: `Variant[String[1], Hash]`

The name of the database.
The default is `DB01`
To customize this consistently use the hiera key `ora_profile::database::dbname`.
This parameter can also be defined as Hash in which case the key(s) of the Hash are the name of the database(s).
The defaults for all the database(s) in the Hash are the ones given to the db_definition class.
In addition all properties and parameters taken by ora_database can be defined in hiera data.

##### `log_size`

Data type: `String[1]`

The log ize to use.
The default is : `100M`

##### `user_tablespace_size`

Data type: `String[1]`

The size for the `USER` tablespace.
The default value is `50M`

##### `system_tablespace_size`

Data type: `String[1]`

The size for the `SYSTEM` tablespace.
The default value is `50M`

##### `temporary_tablespace_size`

Data type: `String[1]`

The size for the `TEMP` tablespace.
The default value is `50M`

##### `undo_tablespace_size`

Data type: `String[1]`

The size for the `UNDO` tablespace.
The default value is `50M`

##### `sysaux_tablespace_size`

Data type: `String[1]`

The size for the `SYSAUX` tablespace.
The default value is `50M`

##### `system_password`

Data type: `Easy_type::Password`

The `system` password to use for the database.
The default value is: `Welcome01`

##### `sys_password`

Data type: `Easy_type::Password`

The `sys` password to use for the database.
The default value is: `Change_on_1nstall`

##### `container_database`

Data type: `Enum['enabled','disabled']`

Database is a container for pluggable databases.
When you want to add pluggable database to this database, specify a value of `enabled`.
The default value is: `disabled`

##### `archivelog`

Data type: `Enum['enabled','disabled']`

The database should be running in archivelog mode.

##### `init_ora_template`

Data type: `String[1]`

The template to use for the init.
ora parameters.
This needs to be an epp template.
The default value is: 'ora_profile/init.ora.epp'

##### `init_ora_params`

Data type: `Hash`

The parameters to use in the template specified in `init_ora_template`.
The default value is:
```yaml
ora_profile::database::db_definition::init_ora_params:
  dbname: "%{lookup('ora_profile::database::db_definition::dbname')}"
  dbdomain: "%{lookup('ora_profile::database::db_definition::dbdomain')}"
  db_create_file_dest: "%{lookup('ora_profile::database::db_definition::data_file_destination')}"
  db_recovery_file_dest: "%{lookup('ora_profile::database::db_definition::db_recovery_file_dest')}"
  db_recovery_file_dest_size: 20480m
  compatible: "%{lookup('ora_profile::database::db_definition::version')}"
  oracle_base: "%{lookup('ora_profile::database::db_definition::oracle_base')}"
  container_database: "%{lookup('ora_profile::database::db_definition::container_database')}"
  sga_target: 1024m
  pga_aggregate_target: 256m
  processes: 300
  open_cursors: 300
  db_block_size: 8192
  log_archive_format: '%t_%s_%r.dbf'
  audit_trail: db
  remote_login_passwordfile: EXCLUSIVE
  undo_tablespace: UNDOTBS1
  memory_target: 0
  memory_max_target: 0
```

##### `data_file_destination`

Data type: `String[1]`

The location of the datafiles.

##### `db_recovery_file_dest`

Data type: `String[1]`

The location of the Flash Recovery Area.

##### `ora_database_override`

Data type: `Hash`

A hash with database settings that will override the default database settings.

##### `dbdomain`

Data type: `Optional[String[1]]`

The domain of the database.
The default is `$facts['networking']['domain']`

##### `logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

log the outputs of Puppet exec or not.
When you specify `true` Puppet will log all output of `exec` types.
Valid values are:
- `true`
- `false`
- `on_failure`

Default value: `lookup({name => 'logoutput', default_value => 'on_failure'})`

### `ora_profile::database::db_definition_template`

++--++

ora_profile::database::db_definition_template

In this class the database will be created from a template. When using a 'seed' template, this will significantly decrease the time it takes to create a database. Bij default the Oracle supplied General_Purpose template is used, which is probably not the best option for your production environment.
This class is meant to replace the db_definition class by specifying in your yaml file:

```yaml
ora_profile::database::before_sysctl:  my_module::my_class
```

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_definition_template` class.

##### `version`

Data type: `Ora_Install::Version`

The version of Oracle you want to install.
The default is : `12.2.0.1`
To customize this consistently use the hiera key `ora_profile::database::version`.

##### `oracle_home`

Data type: `Stdlib::Absolutepath`

The home directory to use for the Oracle installation.
The default is : `/u01/app/oracle/product/#{version}/db_home1`
To customize this consistently use the hiera key `ora_profile::database::oracle_home`.

##### `oracle_base`

Data type: `Stdlib::Absolutepath`

The base directory to use for the Oracle installation.
The default is : `/u01/app/oracle`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `dbname`

Data type: `String[1]`

The name of the database.
The default is `DB01`
To customize this consistently use the hiera key `ora_profile::database::dbname`.

##### `template_name`

Data type: `String[1]`

The name of the template to use for creating the database
The default value is `General_Purpose.${version}`

##### `template_type`

Data type: `Enum['non-seed','seed']`

What type of template is used for creating the database.
The default value is `seed`

##### `data_file_destination`

Data type: `String[1]`

The location where you want to store your database files.
A filesystem or ASM location can be specified.
The default value is `+DATA`

##### `recovery_area_destination`

Data type: `String[1]`

The location where you want to store your flash recovery area.
A filesystem or ASM location can be specified.
The default value is `+RECO`

##### `sample_schema`

Data type: `Enum['TRUE','FALSE']`

Specify if you want the sample schemas installed in your database.
The default value is `FALSE`

##### `memory_mgmt_type`

Data type: `Enum['AUTO','AUTO_SGA','CUSTOM_SGA']`

How the database memory should be managed.
The default value is `AUTO_SGA`

##### `storage_type`

Data type: `Enum['FS','CFS','ASM']`

What type of storage is used for your database.
The default value is `ASM`

##### `puppet_download_mnt_point`

Data type: `String[1]`

Where to get the source of your template from.
This is the module where the xml file for your template is stored as a puppet template(erb).
The default value is `ora_profile`

##### `system_password`

Data type: `Easy_type::Password`

The `system` password to use for the database.
The default value is: `Welcome01`

##### `sys_password`

Data type: `Easy_Type::Password`

The `sys` password to use for the database.
The default value is: `Change_on_1nstall`

##### `db_conf_type`

Data type: `Enum['SINGLE','RAC','RACONE']`

The type of database that needs to be installed.
Valid values are:
- `SINGLE`
- `RAC`
- `RACONE`
The default value is `SINGLE`

##### `log_size`

Data type: `String[1]`

The log ize to use.
The default is : `100M`

##### `dbdomain`

Data type: `Optional[String[1]]`

The domain of the database.
The default is `$facts['networking']['domain']`

##### `logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

log the outputs of Puppet exec or not.
When you specify `true` Puppet will log all output of `exec` types.
Valid values are:
- `true`
- `false`
- `on_failure`

Default value: `lookup({name => 'logoutput', default_value => 'on_failure'})`

### `ora_profile::database::db_init_params`

++--++

ora_profile::database::db_init_params

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_init_params` class.

##### `parameters`

Data type: `Hash`

The Hash with parameters that need to be configured.
The keys of the hash represent the parameter you want to set.
Notation: '<scope>/<parameter_name>[:for_sid][@sid]'
```yaml
ora_profile::database::asm_init_params::parameters:
  memory/asm_power_limit:
    ensure: present
    value: 1024
  spfile/asm_power_limit:
    ensure: present
    value: 1024
```
```yaml
ora_profile::database::db_init_params::parameters:
  memory/archive_lag_target:
    ensure: present
    value: 1800
  spfile/archive_lag_target:
    ensure: present
    value: 1800
```
See: [ora_init_params](https://www.enterprisemodules.com/docs/ora_config/ora_init_param.html)

Default value: `{}`

### `ora_profile::database::db_listener`

++--++

ora_profile::database::db_listener

It installs the specified version of the SQL*net software and start's the listener.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_listener` class.

##### `oracle_home`

Data type: `Stdlib::Absolutepath`

The home directory to use for the Oracle installation.
The default is : `/u01/app/oracle/product/#{version}/db_home1`
To customize this consistently use the hiera key `ora_profile::database::oracle_home`.

##### `oracle_base`

Data type: `Stdlib::Absolutepath`

The base directory to use for the Oracle installation.
The default is : `/u01/app/oracle`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `os_user`

Data type: `String[1]`

The OS user to use for Oracle install.
The default is : `oracle`
To customize this consistently use the hiera key `ora_profile::database::os_user`.

##### `dba_group`

Data type: `String[1]`

The group to use for Oracle DBA users.
The default is : `dba`
To customize this consistently use the hiera key `ora_profile::database::dba_group`.

##### `sqlnet_version`

Data type: `Ora_install::ShortVersion`

The SQLnet version to use.
The default is: 12.2

##### `dbname`

Data type: `Variant[String[1], Hash]`

The name of the database.
The default is `DB01`
To customize this consistently use the hiera key `ora_profile::database::dbname`.
This parameter can also be defined as Hash in case you need multiple listeners.
The keys of the hash are the database names, and for every key you can specify all valid parameters for the class.
The defaults for all key(s) in the Hash are the ones given to the class.

### `ora_profile::database::db_patches`

++--++

ora_profile::database::db_patches

It also contains the definition of the required `Opatch` version.

The class allows you to specify a patch level and optionally include the OJVM pacthes for the level specified.
A patch_list to specify additional patches is also supported.

Keep in mind that when changing the patch level and/or adding patches will cause the listener(s) and database(s) to be stopped and started.

Applying patches to database software in a RAC environment is only supported on initial run.
There is no support yet to apply patches on a running system.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_patches` class.

##### `level`

Data type: `String[1]`

The patch level the database or grid infrastructure should be patched to.
Default value is: `NONE`
Valid values depend on your database/grid version, but it should like like below:
- `OCT2018RU`
- `JAN2019RU`
- `APR2019RU`
- etc...

##### `include_ojvm`

Data type: `Boolean`

Specify if the OJVM patch for the patch level should also be installed.
Default value is: `false`

##### `patch_file`

Data type: `String[1]`

The file containing the required Opatch version.
The default value is: `p6880880_122010_Linux-x86-64`

##### `oracle_home`

Data type: `Stdlib::Absolutepath`

The home directory to use for the Oracle installation.
The default is : `/u01/app/oracle/product/#{version}/db_home1`
To customize this consistently use the hiera key `ora_profile::database::oracle_home`.

##### `opversion`

Data type: `String[1]`

The version of OPatch that is needed.
If it is not installed, Puppet will install the specfied version.
If you have defined patches for multiple homes, this version of the OPatch utility will be installed
in all of these homes from the patch_file specified. Recent versions of the OPatch utility are exactly
the same for Oracle versions 12.1 through 19, so it doesn't matter for which Oracle version you have
downloaded it.
The default value is: `12.2.0.1.13`

##### `os_user`

Data type: `String[1]`

The OS user to use for Oracle install.
The default is : `oracle`
To customize this consistently use the hiera key `ora_profile::database::os_user`.

##### `patch_list`

Data type: `Hash`

The list of patches to apply.
The default value is : `{}`

##### `logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

log the outputs of Puppet exec or not.
When you specify `true` Puppet will log all output of `exec` types.
Valid values are:
- `true`
- `false`
- `on_failure`

Default value: `lookup({name => 'logoutput', default_value => 'on_failure'})`

### `ora_profile::database::db_profiles`

++--++

ora_profile::database::db_profiles

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_profiles` class.

##### `list`

Data type: `Hash`

A list of dataaase profiles to define.
The default value is: {}
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your Oracle profiles, to override this class and  add your own puppet implementation. This is much better maintainable
and adds more consistency.

### `ora_profile::database::db_services`

++--++

ora_profile::database::db_services

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_services` class.

##### `dbname`

Data type: `String[1]`

The name of the database.
The default is `DB01`
To customize this consistently use the hiera key `ora_profile::database::dbname`.

##### `domain_name`

Data type: `Optional[String[1]]`



### `ora_profile::database::db_software`

++--++

ora_profile::database::db_software

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_software` class.

##### `version`

Data type: `Ora_Install::Version`

The version of Oracle you want to install.
The default is : `12.2.0.1`
To customize this consistently use the hiera key `ora_profile::database::version`.

##### `database_type`

Data type: `Enum['SE2', 'SE', 'EE', 'SEONE']`

The type of database to define.
The default value is: `SE2`.

##### `dirs`

Data type: `Array[Stdlib::Absolutepath]`

The directories to create as part of the installation.
The default value is:
```yaml
ora_profile::database::db_software::dirs:
  - /u02
  - /u03
  - /u02/oradata
  - /u03/fast_recovery_area
```

##### `dba_group`

Data type: `String[1]`

The group to use for Oracle DBA users.
The default is : `dba`
To customize this consistently use the hiera key `ora_profile::database::dba_group`.

##### `oper_group`

Data type: `String[1]`

The oper group for the database.
The default is : `oper`

##### `os_user`

Data type: `String[1]`

The OS user to use for Oracle install.
The default is : `oracle`
To customize this consistently use the hiera key `ora_profile::database::os_user`.

##### `oracle_base`

Data type: `Stdlib::Absolutepath`

The base directory to use for the Oracle installation.
The default is : `/u01/app/oracle`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `oracle_home`

Data type: `Variant[Stdlib::Absolutepath, Hash]`

The home directory to use for the Oracle installation.
The default is : `/u01/app/oracle/product/#{version}/db_home1`
To customize this consistently use the hiera key `ora_profile::database::oracle_home` for a single ORACLE_HOME.
This parameter can also be specified as Hash if you need to install multiple ORACLE_HOME's.
The keys of the hash are just a name.
For every key all parameters that are valid for ora_install::installdb can be specified.
For example:
```yaml
ora_profile::database::db_software::oracle_home:
  18cORACLE_HOME1:
    version:     "%{lookup('ora_profile::database::version')}"
    file:        "%{lookup('ora_profile::database::db_software::file_name')}"
    oracle_home: "/u01/app/oracle/product/%{lookup('ora_profile::database::version')}/db_home1"
  18cORACLE_HOME2:
    version:     "%{lookup('ora_profile::database::version')}"
    file:        "%{lookup('ora_profile::database::db_software::file_name')}"
    oracle_home: "/u01/app/oracle/product/%{lookup('ora_profile::database::version')}/db_home2"
  12cR1ORACLE_HOME1:
    version:     12.1.0.2
    file:        linuxamd64_12102_database
    oracle_home: /u01/app/oracle/product/12.1.0.2/db_home1
  12cR1ORACLE_HOME2:
    version:     12.1.0.2
    file:        linuxamd64_12102_database
    oracle_home: /u01/app/oracle/product/12.1.0.2/db_home2
  12cR1ORACLE_HOME3:
    version:     12.1.0.2
    file:        linuxamd64_12102_database
    oracle_home: /u01/app/oracle/product/12.1.0.2/db_home3
  12cR2ORACLE_HOME1:
    version:      12.2.0.1
    file:         linuxx64_12201_database
    oracle_home: /u01/app/oracle/product/12.2.0.1/db_home1
```

##### `source`

Data type: `String[1]`

The location where the classes can find the software.
You can specify a local directory, a Puppet url or an http url.
The default is : `puppet:///modules/software/`
To customize this consistently use the hiera key `ora_profile::database::source`.

##### `file_name`

Data type: `String[1]`

The file name containing the Oracle database software kit.
The default is: `linuxx64_12201_database`

##### `bash_profile`

Data type: `Boolean`

Whether or not to deploy bash_profile for $os_user or $grid_user
The default is : `true`

##### `bash_additions`

Data type: `String`

The text to add at the end of the bash_profile.
This parameter will only be used when you have specified `true` for the parameter `bash_profile`
The default value is an empty string.

### `ora_profile::database::db_startup`

++--++

ora_profile::database::db_startup

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_startup` class.

##### `oracle_home`

Data type: `Stdlib::Absolutepath`

The home directory to use for the Oracle installation.
The default is : `/u01/app/oracle/product/#{version}/db_home1`
To customize this consistently use the hiera key `ora_profile::database::oracle_home`.

##### `dbname`

Data type: `String[1]`

The name of the database.
The default is `DB01`
To customize this consistently use the hiera key `ora_profile::database::dbname`.

##### `db_type`

Data type: `Enum['database','grid']`

The type of the database used to specify if the database should be started by an init script or srvctl.
Valid values are:
- `grid`
- `database`
The default value is: 'database'

### `ora_profile::database::db_tablespaces`

++--++

ora_profile::database::db_tablespaces

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_tablespaces` class.

##### `list`

Data type: `Hash`

A list of database tablespaces to define.
The default value is: `{}`
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your Oracle profiles, to override this class and  add your own puppet implementation. This is much better maintainable
and adds more consistency.

### `ora_profile::database::db_users`

++--++

ora_profile::database::db_users

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::db_users` class.

##### `list`

Data type: `Hash`

A list of database users to define.
The default value is: `{}`
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your Oracle profiles, to override this class and  add your own puppet implementation. This is much better maintainable
and adds more consistency.

### `ora_profile::database::disable_thp`

++--++

ora_profile::database::disable_thp

As documented in Oracle support ALERT <https://support.oracle.com/epmos/faces/DocumentDisplay?id=1557478.1>,
the class will disable Transparent HugePages on RedHat os family starting with version 6.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

### `ora_profile::database::em_license`

++--++

ora_profile::database::em_license

--++--

### `ora_profile::database::firewall`

++--++

ora_profile::database::firewall

When you are using a Redhat flavored version lower then release 7, this module uses the `puppetlabs-firewall` module to manage the `iptables` settings. When using a version 7 or higher, the puppet module `crayfishx-firewalld` to manage the `firewalld daemon`.

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::firewall` class.

##### `ports`

Data type: `Hash`

A list of TCP ports to open in the firewall.
The default value is: `[1521]`

##### `manage_service`

Data type: `Boolean`

Using this setting you can specify if you want this module to manage the firewall service.
The default value is `true` and will make sure the firewall service is started and enabled.

### `ora_profile::database::firewall::firewalld`

++--++

ora_profile::database::firewall::firewalld

Here is an example:

```puppet
  include ora_profile::database::firewall::firewalld
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::firewall::firewalld` class.

##### `ports`

Data type: `Hash`

A list of TCP ports to open in the firewall.
The default value is: `[1521]`

##### `manage_service`

Data type: `Boolean`

Using this setting you can specify if you want this module to manage the firewall service.
The default value is `true` and will make sure the firewall service is started and enabled.

##### `cluster_nodes`

Data type: `Optional[Array]`

An array with cluster node names for RAC.
Example:
```yaml
ora_profile::database::cluster_nodes:
- node1
- node2
```

### `ora_profile::database::firewall::iptables`

++--++

ora_profile::database::firewall::iptables

Here is an example:

```puppet
  include ora_profile::database::firewall::iptables
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::firewall::iptables` class.

##### `ports`

Data type: `Hash`

A list of TCP ports to open in the firewall.
The default value is: `[1521]`

##### `manage_service`

Data type: `Boolean`

Using this setting you can specify if you want this module to manage the firewall service.
The default value is `true` and will make sure the firewall service is started and enabled.

##### `cluster_nodes`

Data type: `Optional[Array]`

An array with cluster node names for RAC.
Example:
```yaml
ora_profile::database::cluster_nodes:
- node1
- node2
```

### `ora_profile::database::rac::authenticated_nodes`

++--++

ora_profile::database::rac::authenticated_nodes

Only applicable for RAC.

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::rac::authenticated_nodes` class.

##### `oracle_private_key`

Data type: `String[1]`

The private key of the oracle user.

##### `grid_private_key`

Data type: `String[1]`

The private key of the grid user.

##### `keys`

Data type: `Hash`

Hash with users and the public keys they will get.
Here is an example:
```yaml
ora_profile::database::rac::authenticated_nodes::keys:
  oracle_for_grid:
    ensure: present
    user: grid
    type: rsa
    key: '<public key>'
  grid_for_oracle:
    ensure: present
    user: oracle
    type: rsa
    key: '<public key>'
```

Default value: `{}`

### `ora_profile::database::tmpfiles`

++--++

ora_profile::tmpfiles

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.

First level is the config file in /etc/tmpfiles.d it will have the .conf extension
We can group multiple directories in a configfile with mixed config types


Example:
ora_profile::database::tmpfiles::list:
 oracle:
   - dir:      '/var/tmp/.oracle'
     mode:     'x'
   - dir:      '/var/tmp/test'
     mode:     'd'
     perm:     '0755'
     owner:    'root'
     group:    'root'
     interval: '12h'
 linux:
   - dir:   '/tmp/.screenrc'
     mode:  'x'


use 'man 5 tmpfiles.d' for all config options

Module default:
ora_profile::database::tmpfiles::list:
 oracle:
   - dir: '/tmp/.oracle'
     mode: 'x'
   - dir: '/var/tmp/.oracle'
     mode: 'x'


--++--

#### Parameters

The following parameters are available in the `ora_profile::database::tmpfiles` class.

##### `list`

Data type: `Hash`

The OS limits created for Oracle.
The defaults are:

### `ora_profile::extracted_database`

ora_profile::database

A description of what this defined type does

++--++
--++--

#### Examples

##### 

```puppet
ora_profile::database { 'database_name': }
```

#### Parameters

The following parameters are available in the `ora_profile::extracted_database` class.

##### `version`

Data type: `Ora_Install::Version`



##### `dbname`

Data type: `String[1]`



##### `os_user`

Data type: `String[1]`



##### `dba_group`

Data type: `String[1]`



##### `install_group`

Data type: `String[1]`



##### `source`

Data type: `String[1]`



##### `oracle_base`

Data type: `Stdlib::Absolutepath`



##### `oracle_home`

Data type: `Stdlib::Absolutepath`



##### `ora_inventory_dir`

Data type: `Stdlib::Absolutepath`



##### `db_control_provider`

Data type: `String[1]`



##### `download_dir`

Data type: `Stdlib::Absolutepath`



##### `temp_dir`

Data type: `Stdlib::Absolutepath`



##### `oracle_user_password`

Data type: `Optional[String]`



Default value: ``undef``

##### `em_license`

Data type: `Optional[String]`



Default value: ``undef``

##### `authenticated_nodes`

Data type: `Optional[String]`



Default value: ``undef``

##### `before_em_license`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_em_license`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `sysctl`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_sysctl`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_sysctl`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `limits`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_limits`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_limits`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `groups_and_users`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_groups_and_users`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_groups_and_users`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `packages`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_packages`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_packages`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `firewall`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_firewall`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_firewall`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `tmpfiles`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_tmpfiles`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_tmpfiles`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `db_software`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_db_software`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_db_software`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `db_patches`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_db_patches`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_db_patches`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `extracted_database_definition`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_extracted_database_definition`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_extracted_database_definition`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `extracted_init_params`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_extracted_init_params`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_extracted_init_params`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `extracted_services`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_extracted_services`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_extracted_services`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `extracted_tablespaces`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_extracted_tablespaces`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_extracted_tablespaces`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `extracted_profiles`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_extracted_profiles`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_extracted_profiles`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `extracted_users`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_extracted_users`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_extracted_users`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `db_startup`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `before_db_startup`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `after_db_startup`

Data type: `Optional[String[1]]`



Default value: ``undef``

### `ora_profile::oem_agent`

++--++

ora_profile::oem_agent

In it's core just adding:

```
contain ::ora_profile::oem_server
```

Is enough to get Oracle Enterprise Manager installed on your system.

But sometimes you have specific uses cases that are not handled well by the standard classes. This profile class allows you to add your own code to the execution.

## Stages

Defining and starting an Oracle Enterprise Manager installation on you system goes through several stages(These are not puppet stages):

- `em_license`         (Deploy Enterprise Modules license)
- `sysctl`             (Set all required sysctl parameters)
- `groups_and_users`   (Create required groups and users)
- `firewall`           (Open required firewall rules)
- `server_limits`      (Set all required OS limits)
- `server_packages`    (Install all required packages)
- `server`             (Install the Oracle Enterprise Manager software)

All these stages have a default implementation. This implementation is suitable to get started with. These classes all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

## before classes

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `systctl` stage is done and before the `groups_and_users` is started. You can do this by adding the next line to your yaml data:

```yaml
ora_profile::oem::before_groups_and_users:   my_profile::my_extra_class
```

## after classes

You can do the same when you want to add code after one of the stage classes:

```yaml
ora_profile::oem::after_groups_and_users:   my_profile::my_extra_class
```

## Skipping

Sometimes organisation use different modules and mechanisms to implement a feature and you want to skip the class:

```yaml
ora_profile::oem::server_packages:   skip
```

## Replacing

Or provide your own implementation:

```yaml
ora_profile::oem::server_packages:   my_profile::my_own_implementation
```

This mechanism can be used for all named stages and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.

Here is an example:
```puppet
contain ::ora_profile::oem_server
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::oem_agent` class.

##### `before_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_em_license:  my_module::my_class
```

Default value: ``undef``

##### `em_license`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `em_license`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::em_license:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::em_license:  skip
```

Default value: ``undef``

##### `after_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_em_license:  my_module::my_class
```

Default value: ``undef``

##### `before_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_sysctl:  my_module::my_class
```

Default value: ``undef``

##### `sysctl`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `sysctl`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::sysctl:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::sysctl:  skip
```

Default value: ``undef``

##### `after_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_sysctl:  my_module::my_class
```

Default value: ``undef``

##### `before_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `groups_and_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `groups_and_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::groups_and_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::groups_and_users:  skip
```

Default value: ``undef``

##### `after_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `before_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_firewall:  my_module::my_class
```

Default value: ``undef``

##### `firewall`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `firewall`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::firewall:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::firewall:  skip
```

Default value: ``undef``

##### `after_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_firewall:  my_module::my_class
```

Default value: ``undef``

##### `before_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::before_limits:  my_module::my_class
```

Default value: ``undef``

##### `limits`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `limits`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::limits:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::limits:  skip
```

Default value: ``undef``

##### `after_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_agent::after_limits:  my_module::my_class
```

Default value: ``undef``

##### `before_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::before_packages:  my_module::my_class
```

Default value: ``undef``

##### `packages`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `packages`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::packages:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::packages:  skip
```

Default value: ``undef``

##### `after_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::after_packages:  my_module::my_class
```

Default value: ``undef``

##### `before_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::before_software:  my_module::my_class
```

Default value: ``undef``

##### `software`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `software`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::software:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::software:  skip
```

Default value: ``undef``

##### `after_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::after_software:  my_module::my_class
```

Default value: ``undef``

##### `standalone`

Data type: `Optional[Boolean]`

Indicate if this is a standalone installation (Only install OEM Agent) or not (Installed on a database server)
Valid values are `true` and `false`.

Default value: ``undef``

### `ora_profile::oem_agent::software`

++--++

ora_profile::oem_agent::software

--++--

#### Parameters

The following parameters are available in the `ora_profile::oem_agent::software` class.

##### `agent_base_dir`

Data type: `Stdlib::Absolutepath`

The directory to use as instance home.

##### `agent_registration_password`

Data type: `Easy_type::Password`

The password to use to register the agent.

##### `download_dir`

Data type: `Stdlib::Absolutepath`

The directory where the Puppet software puts all downloaded files.
Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
The default value is: `/install`
To customize this consistently use the hiera key `ora_profile::database::download_dir`.

##### `em_upload_port`

Data type: `Integer`

The port number of the HTTP port for the upload service.
The default value is: `1159`

##### `install_agent`

Data type: `Boolean`

Flag to indicate the OEM Agent needs to be installed or not.
In case your OEM Server hasn't been installed yet, set this to `false`

Default value: ``true``

##### `install_group`

Data type: `String`

The group to use for Oracle install.
The default is : `oinstall`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `install_version`

Data type: `String`

The version you want to install.
The default value is: `12.1.0.5.0`

##### `oms_host`

Data type: `String`

The OMS host to use.

##### `oms_port`

Data type: `Integer`

The IP port to use for connecting to the OMS host.

##### `ora_inventory_dir`

Data type: `Stdlib::Absolutepath`

The directory that contains the oracle inventory.
The default value is: `/oracle_base/oraInventory`
To customize this consistently use the hiera key `ora_profile::database::ora_inventory_dir`.

##### `oracle_base`

Data type: `Stdlib::Absolutepath`

The base directory to use for the Oracle installation.
The default is : `/u01/app/oracle`
To customize this consistently use the hiera key `ora_profile::database::install_group`.

##### `os_user`

Data type: `String`

The OS user to use for Oracle install.
The default is : `oracle`
To customize this consistently use the hiera key `ora_profile::database::os_user`.

##### `sysman_password`

Data type: `Easy_type::Password`

The password to use for sysman.

##### `sysman_user`

Data type: `String`

The sysman user.
The default value is: `sysman`

##### `temp_dir`

Data type: `Stdlib::Absolutepath`

Directory to use for temporary files.

##### `version`

Data type: `String`

The agent version to be installed
- `12.1.0.4`
- `12.1.0.5`
- `13.1.0.0`
- `13.2.0.0`
- `13.3.0.0`
- `13.4.0.0`
- `13.5.0.0`

### `ora_profile::oem_server`

++--++

ora_profile::oem_server

In it's core just adding:

```
contain ::ora_profile::oem_server
```

Is enough to get Oracle Enterprise Manager installed on your system.

But sometimes you have specific uses cases that are not handled well by the standard classes. This profile class allows you to add your own code to the execution.

## Stages

Defining and starting an Oracle Enterprise Manager installation on you system goes through several stages(These are not puppet stages):

- `em_license`         (Deploy Enterprise Modules license)
- `sysctl`             (Set all required sysctl parameters)
- `groups_and_users`   (Create required groups and users)
- `firewall`           (Open required firewall rules)
- `limits`             (Set all required OS limits)
- `packages`           (Install all required packages)
- `software`           (Install the Oracle Enterprise Manager software)

All these stages have a default implementation. This implementation is suitable to get started with. These classes all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

## before classes

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `systctl` stage is done and before the `groups_and_users` is started. You can do this by adding the next line to your yaml data:

```yaml
ora_profile::oem_server::before_groups_and_users:   my_profile::my_extra_class
```

## after classes

You can do the same when you want to add code after one of the stage classes:

```yaml
ora_profile::oem_server::after_groups_and_users:   my_profile::my_extra_class
```

## Skipping

Sometimes organisation use different modules and mechanisms to implement a feature and you want to skip the class:

```yaml
ora_profile::oem_server::packages:   skip
```

## Replacing

Or provide your own implementation:

```yaml
ora_profile::oem_server::packages:   my_profile::my_own_implementation
```

This mechanism can be used for all named stages and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.

Here is an example:
```puppet
contain ::ora_profile::oem_server
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::oem_server` class.

##### `after_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_em_license:  my_module::my_class
```

Default value: ``undef``

##### `after_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_firewall:  my_module::my_class
```

Default value: ``undef``

##### `after_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `after_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::after_limits:  my_module::my_class
```

Default value: ``undef``

##### `after_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::after_packages:  my_module::my_class
```

Default value: ``undef``

##### `after_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::after_software:  my_module::my_class
```

Default value: ``undef``

##### `after_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::after_sysctl:  my_module::my_class
```

Default value: ``undef``

##### `before_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_em_license:  my_module::my_class
```

Default value: ``undef``

##### `before_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_firewall:  my_module::my_class
```

Default value: ``undef``

##### `before_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### `before_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::before_limits:  my_module::my_class
```

Default value: ``undef``

##### `before_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::before_packages:  my_module::my_class
```

Default value: ``undef``

##### `before_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `software` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::before_software:  my_module::my_class
```

Default value: ``undef``

##### `before_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::before_sysctl:  my_module::my_class
```

Default value: ``undef``

##### `em_license`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `em_license`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::em_license:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::em_license:  skip
```

Default value: ``undef``

##### `firewall`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `firewall`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::firewall:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::firewall:  skip
```

Default value: ``undef``

##### `groups_and_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `groups_and_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::groups_and_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::groups_and_users:  skip
```

Default value: ``undef``

##### `limits`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `limits`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::limits:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::limits:  skip
```

Default value: ``undef``

##### `packages`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `packages`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::packages:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::packages:  skip
```

Default value: ``undef``

##### `software`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `software`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::software:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::oem_server::software:  skip
```

Default value: ``undef``

##### `standalone`

Data type: `Optional[Boolean]`

Indicate if this is a standalone (Only install OEM) or not (Install database and OEM)
Valid values are `true` and `false`.

Default value: ``undef``

##### `sysctl`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `sysctl`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::sysctl:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
ora_profile::database::sysctl:  skip
```

Default value: ``undef``

### `ora_profile::oem_server::software`

++--++

ora_profile::oem_server::software

--++--

#### Parameters

The following parameters are available in the `ora_profile::oem_server::software` class.

##### `agent_base_dir`

Data type: `Stdlib::Absolutepath`

The directory to use as base for the agent software.

##### `agent_registration_password`

Data type: `Easy_type::Password`

The password to use to register the agent.

##### `database_hostname`

Data type: `String[1]`

The DNS name of the database host.

##### `database_listener_port`

Data type: `Integer`

The IP port for the database listener.
The default value is: `1521`

##### `database_service_sid_name`

Data type: `String[1]`

The database service SID name for the database.

##### `database_sys_password`

Data type: `Easy_type::Password`

The password of the SYS user of the database.

##### `deployment_size`

Data type: `String[1]`

The size of the deployment.
Valid values are:
- `SMALL`
- `MEDIUM`
- `LARGE`
The default value is: `SMALL`

##### `download_dir`

Data type: `Stdlib::Absolutepath`

The directory where the Puppet software puts all downloaded files.
Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
The default value is: `/install`
To customize this consistently use the hiera key `ora_profile::database::download_dir`.

##### `file`

Data type: `String[1]`

The source file to use.

##### `group`

Data type: `String[1]`

The dba group for ASM.
The default is : `asmdba`
To customize this consistently use the hiera key `ora_profile::database::asm_software::group`.

##### `logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

log the outputs of Puppet exec or not.
When you specify `true` Puppet will log all output of `exec` types.
Valid values are:
- `true`
- `false`
- `on_failure`

##### `ora_inventory_dir`

Data type: `Stdlib::Absolutepath`

The directory that contains the oracle inventory.
The default value is: `/oracle_base/oraInventory`
To customize this consistently use the hiera key `ora_profile::database::ora_inventory_dir`.

##### `oracle_base_dir`

Data type: `Stdlib::Absolutepath`

A directory to use as Oracle base directory.

##### `oracle_home_dir`

Data type: `Stdlib::Absolutepath`

A directory to be used as Oracle home directory for this software.

##### `puppet_download_mnt_point`

Data type: `String[1]`

Where to get the source of your template from.
This is the module where the xml file for your template is stored as a puppet template(erb).
The default value is `ora_profile`

##### `software_library_dir`

Data type: `Stdlib::Absolutepath`

The directory to use for the software library.

##### `swonly`

Data type: `Boolean`

Only install the software without configuration (true) or not (false).
The default value is: `false`

##### `sysman_password`

Data type: `Easy_type::Password`

The password to use for sysman.

##### `temp_dir`

Data type: `Stdlib::Absolutepath`

Directory to use for temporary files.

##### `user`

Data type: `String[1]`

The user used for the specified installation.
The install class will not create the user for you. You must do that yourself.
The default value is: `oracle`

##### `version`

Data type: `String[1]`

The server version to be installed
- `12.1.0.4`
- `12.1.0.5`
- `13.1.0.0`
- `13.2.0.0`
- `13.3.0.0`
- `13.4.0.0`
- `13.5.0.0`

##### `weblogic_password`

Data type: `Easy_type::Password`

The password to use for WebLogic.

##### `weblogic_user`

Data type: `String[1]`

The username to use for WebLogic.
The default value is: `weblogic`

##### `zip_extract`

Data type: `Boolean`

The specified source file is a zip file that needs te be extracted.
When you specify a value of false, the source attribute must contain a reference to a directory instead of a zip file.
The default value is: `true`

### `ora_profile::secured_database`

ora_profile::secured_db

A description of what this class does

++--++

ora_profile::secured_database

In it's core just adding:

```
contain ora_profile::secured_database
```

Is enough to get a secured Oracle database running on your system.

This profile class is based on the more generic [`ora_profile::database`](./database.html) class, but extends this class with securing the database conforming to the Oracle Center for Internet Security (CIS) rules.

--++--

#### Examples

##### 

```puppet
include ora_profile::secured_db
```

## Defined types

### `ora_profile::database::asm_storage::partition`

ora_profile::database::asm_storage::partition

++--++

ora_profile::database::asm_storage::partition

.

Here is an example:

```puppet
  include ora_profile::database::asm_storage::partition
```

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::asm_storage::partition` defined type.

##### `raw_device`

Data type: `Stdlib::Absolutepath`

The device that needs to be partitioned.

##### `table_type`

Data type: `Enum['gpt','msdos']`

The type of partition table.

Default value: `'msdos'`

##### `wait_for_device`

Data type: `Boolean`

Should we wait for the device to be available?

Default value: ``false``

##### `start`

Data type: `Optional[Easy_type::Size]`

The start point of the partition.

Default value: ``undef``

##### `end`

Data type: `Optional[Easy_type::Size]`

The end point of the partition.

Default value: ``undef``

### `ora_profile::database::authenticated_nodes::user_equivalence`

++--++

ora_profile::database::authenticated_nodes::user_equivalence

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::authenticated_nodes::user_equivalence` defined type.

##### `private_key`

Data type: `String`

The private key of the user.

##### `nodes`

Data type: `Array[String[1]]`

The cluster nodes.

Default value: `['localhost']`

### `ora_profile::database::rac::instance`

++--++

ora_profile::database::rac::instance

Here is an example:
  ora_profile::database::rac::instance{'instance_name'}

--++--

#### Parameters

The following parameters are available in the `ora_profile::database::rac::instance` defined type.

##### `on`

Data type: `String[1]`

The instance for which it should be executed.

##### `number`

Data type: `Integer`

The instance number.

##### `thread`

Data type: `Integer`

The thread of the instance.

##### `datafile`

Data type: `String[1]`

The datafile for the Undo tablespace for the instance.

##### `undo_initial_size`

Data type: `Easy_type::Size`

The size of the Undo tablespace for the instance.

##### `undo_next`

Data type: `Easy_type::Size`

The size of the next extent for the Undo tablesapce of the instance.

##### `undo_autoextend`

Data type: `Enum['on','off']`

Auto extensibility of the Undo tablespace for the instance.

##### `undo_max_size`

Data type: `Easy_type::Size`

The maximum size of the datafile of the Undo tablespace for the instance.

##### `log_size`

Data type: `Easy_type::Size`

The size of the redolog files of the instance.

## Functions

### `set_param`

Type: Ruby 4.x API

See the file "LICENSE" for the full license governing this code.

Returns the value for requested parameter.
Currently supported parameters:
- instance_name
- instance_number
- thread_number

rubocop: disable Metrics/AbcSize
rubocop: disable Metrics/CyclomaticComplexity
rubocop: disable Metrics/PerceivedComplexity
rubocop: disable Metrics/MethodLength

#### `set_param(String $param_name, String $dbname, Optional[Undef] $cluster_nodes)`

The set_param function.

Returns: `String`

##### `param_name`

Data type: `String`



##### `dbname`

Data type: `String`



##### `cluster_nodes`

Data type: `Optional[Undef]`



#### `set_param(String $param_name, String $dbname, Array $cluster_nodes)`

The set_param function.

Returns: `Any`

##### `param_name`

Data type: `String`



##### `dbname`

Data type: `String`



##### `cluster_nodes`

Data type: `Array`



